@@ -2,7 +2,7 @@
 #
 # Format - A class for writing the Excel XLSX Worksheet file.
 #
-# Copyright 2013-2016, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2018, John McNamara, jmcnamara@cpan.org
 #
 
 # Package imports.
@@ -22,11 +22,13 @@ class Format(xmlwriter.XMLwriter):
     #
     ###########################################################################
 
-    def __init__(self, properties={}, xf_indices=None, dxf_indices=None):
+    def __init__(self, properties=None, xf_indices=None, dxf_indices=None):
         """
         Constructor.
 
         """
+        if properties is None:
+            properties = {}
 
         super(Format, self).__init__()
 
@@ -57,7 +59,8 @@ class Format(xmlwriter.XMLwriter):
         self.font_condense = 0
         self.font_extend = 0
         self.theme = 0
-        self.hyperlink = 0
+        self.hyperlink = False
+        self.xf_id = 0
 
         self.hidden = 0
         self.locked = 1
@@ -674,9 +677,9 @@ class Format(xmlwriter.XMLwriter):
         # Set the text_v_align property.
         self.text_v_align = text_v_align
 
-    def set_reading_order(self, reading_order=True):
+    def set_reading_order(self, direction=0):
         # Set the reading_order property.
-        self.reading_order = reading_order
+        self.reading_order = direction
 
     def set_valign(self, align):
         # Set vertical cell alignment. This is required by the constructor
@@ -709,12 +712,11 @@ class Format(xmlwriter.XMLwriter):
         self.theme = theme
 
     def set_hyperlink(self, hyperlink=True):
-        # Set the properties for the hyperlink style. This doesn't
-        # currently work. To be fixed when styles are supported.
-
+        # Set the properties for the hyperlink style. This isn't
+        # currently public. To be fixed when styles are supported.
+        self.xf_id = 1
         self.set_underline(1)
         self.set_theme(10)
-        self.set_align('top')
         self.hyperlink = hyperlink
 
     def set_color_indexed(self, color_index):
@@ -866,7 +868,8 @@ class Format(xmlwriter.XMLwriter):
             self.font_name,
             self.italic,
             self.font_size,
-            self.underline))
+            self.underline,
+            self.theme))
 
         return key
 
